# lot-python

## Installation

```bash
sudo add-apt-repository -y ppa:loliot/ppa &&\
sudo apt install lot
```

```bash
sudo apt update &&\
sudo apt install -y swig python3 python3-dev python3-pip &&\
python3 -m pip install -U pip setuptools
```

```bash
python3 -m pip install lot
```
